# == Class: postfix
#
# Puppet module to install, deploy and configure postfix.
#
class postfix (
  $package              = true,
  $service              = true,
  $enable               = true,
  $postfix_package_name = $postfix::params::postfix_package_name,
  $postfix_service_name = $postfix::params::postfix_service_name,
  # daemon settings
  $domain               = $::domain,
  $origin               = '/etc/mailname',
  $relayhost            = "smtp.${domain}"
) inherits postfix::params {
  case $package {
    true    : { $ensure_package = 'present' }
    false   : { $ensure_package = 'purged' }
    latest  : { $ensure_package = 'latest' }
    default : { fail('package must be true, false or lastest') }
  }

  case $service {
    true    : { $ensure_service = 'running' }
    false   : { $ensure_service = 'stopped' }
    default : { fail('service must be true or false') }
  }

  package { $postfix_package_name:
    ensure => $ensure_package,
  }

  service { $postfix_service_name:
    ensure  => $ensure_service,
    enable  => $enable,
    require => Package[$postfix_package_name]
  }

  file { '/etc/mailname':
    ensure  => $ensure_package,
    path    => '/etc/mailname',
    owner   => 'root',
    group   => 'root',
    mode    => '0644',
    content => template('postfix/mailname.erb'),
    require => Package[$postfix_package_name],
  }

  file { '/etc/postfix/main.cf':
    ensure  => $ensure_package,
    backup  => true,
    path    => '/etc/postfix/main.cf',
    owner   => 'root',
    group   => 'root',
    mode    => '0644',
    content => template('postfix/main.cf.erb'),
    require => Package[$postfix_package_name],
    notify  => Service[$postfix_service_name],
  }

  file { '/etc/postfix/master.cf':
    ensure  => $ensure_package,
    backup  => true,
    path    => '/etc/postfix/master.cf',
    owner   => 'root',
    group   => 'root',
    mode    => '0644',
    content => template('postfix/master.cf.erb'),
    require => Package[$postfix_package_name],
    notify  => Service[$postfix_service_name],
  }

  file { '/etc/postfix/conf.d':
    ensure  => directory,
    path    => '/etc/postfix/conf.d',
    owner   => 'root',
    group   => 'root',
    mode    => '0755',
    require => Package[$postfix_package_name],
    notify  => Service[$postfix_service_name],
  }

  file { '/etc/postfix/conf.d/regexp-canonical':
    ensure  => $ensure_package,
    path    => '/etc/postfix/conf.d/regexp-canonical',
    owner   => 'root',
    group   => 'root',
    mode    => '0644',
    content => template('postfix/regexp-canonical.erb'),
    require => Package[$postfix_package_name],
    notify  => Service[$postfix_service_name],
  }
}
# EOF
